@@ -5,7 +5,6 @@
 package Object::Exercise::Execute;
 use v5.20;
 no warnings;
-use experimental    qw( autoderef );
 
 use Carp;
 
@@ -22,7 +21,7 @@ use Test::More;
 
 our @CARP_NOT   = ( __PACKAGE__ );
 
-our $VERSION    = '3.00';
+our $VERSION    = '3.02';
 $VERSION        = eval "$VERSION";
 
 my @defaultz =
@@ -260,7 +259,7 @@ my $process
         return
     }
 
-    local @globalz{ keys $localz } = values $localz
+    local @globalz{ keys %$localz } = values %$localz
     if $localz;
 
     # if there is no expect value then skip the ok check and just
